@@ -1,9 +1,9 @@
 from __future__ import unicode_literals, print_function
 
 import logging
-from lazy import lazy
 from flask import request, url_for, redirect, current_app
 from werkzeug.wrappers import Response
+from werkzeug.utils import cached_property
 from requests_oauthlib.oauth1_session import TokenRequestDenied, TokenMissing
 from oauthlib.oauth1 import SIGNATURE_HMAC, SIGNATURE_TYPE_AUTH_HEADER
 from oauthlib.common import to_unicode
@@ -14,6 +14,8 @@ from .base import (
     oauth_error,
 )
 from .requests import OAuth1Session
+from flask_dance.utils import invalidate_cached_property
+
 
 log = logging.getLogger(__name__)
 
@@ -50,7 +52,6 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         redirect_url=None,
         redirect_to=None,
         session_class=None,
-        backend=None,
         storage=None,
         **kwargs
     ):
@@ -121,7 +122,6 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
             root_path=root_path,
             login_url=login_url,
             authorized_url=authorized_url,
-            backend=backend,
             storage=storage,
         )
 
@@ -147,7 +147,7 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
 
         self.teardown_app_request(self.teardown_session)
 
-    @lazy
+    @cached_property
     def session(self):
         """
         This is a session between the consumer (your website) and the provider
@@ -169,12 +169,10 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         )
 
     def teardown_session(self, exception=None):
-        lazy.invalidate(self, "session")
+        invalidate_cached_property(self, "session")
 
     def login(self):
-        callback_uri = url_for(
-            ".authorized", next=request.args.get("next"), _external=True
-        )
+        callback_uri = url_for(".authorized", _external=True)
         self.session._client.client.callback_uri = to_unicode(callback_uri)
 
         try:
@@ -187,9 +185,7 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
             log.warning("OAuth 1 request token error: %s", message)
             oauth_error.send(self, message=message, response=response)
             # can't proceed with OAuth, have to just redirect to next_url
-            if "next" in request.args:
-                next_url = request.args["next"]
-            elif self.redirect_url:
+            if self.redirect_url:
                 next_url = self.redirect_url
             elif self.redirect_to:
                 next_url = url_for(self.redirect_to)
@@ -207,9 +203,7 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         the provider (e.g. Twitter) after the user has logged into the
         provider's website and authorized your app to access their account.
         """
-        if "next" in request.args:
-            next_url = request.args["next"]
-        elif self.redirect_url:
+        if self.redirect_url:
             next_url = self.redirect_url
         elif self.redirect_to:
             next_url = url_for(self.redirect_to)
