@@ -22,14 +22,14 @@ def make_nylas_blueprint(
     login_url=None,
     authorized_url=None,
     session_class=None,
-    backend=None,
     storage=None,
 ):
     """
     Make a blueprint for authenticating with Nylas using OAuth 2. This requires
     an API ID and API secret from Nylas. You should either pass them to
     this constructor, or make sure that your Flask application config defines
-    them, using the variables NYLAS_OAUTH_CLIENT_KEY and NYLAS_OAUTH_CLIENT_SECRET.
+    them, using the variables :envvar:`NYLAS_OAUTH_CLIENT_KEY` and
+    :envvar:`NYLAS_OAUTH_CLIENT_SECRET`.
 
     Args:
         client_id (str): The client ID for your developer account on Nylas.
@@ -70,7 +70,6 @@ def make_nylas_blueprint(
         login_url=login_url,
         authorized_url=authorized_url,
         session_class=session_class,
-        backend=backend,
         storage=storage,
     )
     nylas_bp.from_config["client_id"] = "NYLAS_OAUTH_CLIENT_ID"
