@@ -24,14 +24,14 @@ def make_okta_blueprint(
     login_url=None,
     authorization_url=None,
     session_class=None,
-    backend=None,
     storage=None,
 ):
     """
     Make a blueprint for authenticating with Okta using OAuth 2. This requires
     a client ID and client secret from OKta. You should either pass them to
     this constructor, or make sure that your Flask application config defines
-    them, using the variables OKTA_OAUTH_CLIENT_ID and OKTA_OAUTH_CLIENT_SECRET.
+    them, using the variables :envvar:`OKTA_OAUTH_CLIENT_ID` and
+    :envvar:`OKTA_OAUTH_CLIENT_SECRET`.
 
     Args:
         client_id (str): The client ID for your application on Okta.
@@ -70,7 +70,6 @@ def make_okta_blueprint(
         redirect_to=redirect_to,
         login_url=login_url,
         session_class=session_class,
-        backend=backend,
         storage=storage,
     )
     okta_bp.from_config["client_id"] = "OKTA_OAUTH_CLIENT_ID"
